==> hermes-2.4.6.2-265313bb.tar.gz: hermes-2.4.6.2-265313bb/app/jobs/handle_request_state_job.rb <==
# frozen_string_literal: true

# Handle orientation dependencies for a request
class HandleRequestStateJob < ActiveJob::Base
  queue_as :handreqstatelow

  def perform(request_id, type = 'request_creation')
    # kill other pending jobs
    Resque::Job.destroy(
      'handreqstatelow',
      HandleRequestStateJob,
      request_id,
      type
    )

    if request = Hermes::HousingRequest.find_by(id: request_id)
      case type
        # Temporary_disabled_devops_7390
        when 'request_creation'
          if request.request_status === 'INCOMPLETE'
            # request.notify(
            #   key: NOTIFICATION_KEYS[:housing_request][:request_incompleted],
            #   channels: ['email'],
            #   main_only: true
            # )
            HandleRequestStateJob.set(wait: 15.days).perform_later(request.id.to_s, 'request_creation') unless Rails.env.test? # auto re-run (in test when it in perform_enqueued_jobs block it make stack level too deep error)
          end
        when 'required_documents'
          missing_docs = request.housing_request_folder.required_documents.select(&:missing?)
          if missing_docs.any?
            # request.notify(
            #   key: NOTIFICATION_KEYS[:housing_request][:documents_missing],
            #   channels: ['email'],
            #   main_only: true
            # )
            HandleRequestStateJob.set(wait: 72.hours).perform_later(request.id.to_s, 'required_documents') unless Rails.env.test? # auto re-run (in test when it in perform_enqueued_jobs block it make stack level too deep error)
          end
        when 'request_application'
          is_incomplete = request.housing_request_folder.application_status == 'Dossier incomplet'
          if is_incomplete
            request.notify(
              key: NOTIFICATION_KEYS[:housing_request][:application_delay_exceeded],
              channels: ['email'],
              main_only: true
            )
            ### pending instructions ###
            # request.update!(is_active: false)
            ############################
          end
        else
          nil
      end
    end
  end
end

==> hermes-2.4.10.3.tar.gz: hermes-2.4.10.3/app/jobs/handle_request_state_job.rb <==
# frozen_string_literal: true

# Handle orientation dependencies for a request
class HandleRequestStateJob < ActiveJob::Base
  queue_as :handreqstatelow

  def perform(request_id, type = 'request_creation')
    # kill other pending jobs
    Resque::Job.destroy(
      'handreqstatelow',
      HandleRequestStateJob,
      request_id,
      type
    )

    if request = Hermes::HousingRequest.find_by(id: request_id)
      case type
        # Temporary_disabled_devops_7390
        when 'request_creation'
          if request.request_status === 'INCOMPLETE'
            # request.notify(
            #   key: NOTIFICATION_KEYS[:housing_request][:request_incompleted],
            #   channels: ['email'],
            #   main_only: true
            # )
            HandleRequestStateJob.set(wait: 15.days).perform_later(request.id.to_s, 'request_creation') unless Rails.env.test? # auto re-run (in test when it in perform_enqueued_jobs block it make stack level too deep error)
          end
        when 'required_documents'
          missing_docs = request.housing_request_folder.required_documents.select(&:missing?)
          if missing_docs.any?
            # request.notify(
            #   key: NOTIFICATION_KEYS[:housing_request][:documents_missing],
            #   channels: ['email'],
            #   main_only: true
            # )
            HandleRequestStateJob.set(wait: 72.hours).perform_later(request.id.to_s, 'required_documents') unless Rails.env.test? # auto re-run (in test when it in perform_enqueued_jobs block it make stack level too deep error)
          end
        when 'request_application'
          is_incomplete = request.housing_request_folder.application_status == 'Dossier incomplet'
          if is_incomplete
          #   request.notify(
          #     key: NOTIFICATION_KEYS[:housing_request][:application_delay_exceeded],
          #     channels: ['email'],
          #     main_only: true
          #   )
            ### pending instructions ###
            # request.update!(is_active: false)
            ############################
          end
        else
          nil
      end
    end
  end
end
